@@ -61,17 +61,20 @@ def read_mergeh5(path,ori_instruments,fields,start_index,end_index,tidx = 'trade
         return pd.DataFrame()
     mask,amount = gen_idxs(cidx,infoloc,instloc,rsilist,reilist,start_index,end_index)
 
-    if fields:
+    if isinstance(tidx,str):
+            tidx = [tidx]
+    if not isinstance(fields,None.__class__):
         if isinstance(fields,str):
             fields = [fields]
-        if isinstance(tidx,str):
-            tidx = [tidx]
         data = dset[mask][tidx+fields]
     else:
         data = dset[mask]
+    
+    mask2 = ~(data[tidx[0]] == 0)
+    data = data[mask2]
 
     data = pd.DataFrame(data).dropna(axis = 0,how = 'all')
-    data['code'] = np.repeat(labels.values,amount)
+    data['code'] = np.repeat(labels.values,amount)[mask2]
     return data
 
 @print_func_time
